aboutsummaryrefslogtreecommitdiff
path: root/src/argaze/utils/tobii_stream_arscene_display.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/argaze/utils/tobii_stream_arscene_display.py')
-rw-r--r--src/argaze/utils/tobii_stream_arscene_display.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/argaze/utils/tobii_stream_arscene_display.py b/src/argaze/utils/tobii_stream_arscene_display.py
index 336de1f..dabaa9b 100644
--- a/src/argaze/utils/tobii_stream_arscene_display.py
+++ b/src/argaze/utils/tobii_stream_arscene_display.py
@@ -14,14 +14,14 @@ import numpy
def main():
"""
Track ArUcoScene into Tobii Glasses Pro 2 camera video stream.
"""
# Manage arguments
parser = argparse.ArgumentParser(description=main.__doc__.split('-')[0])
parser.add_argument('-t', '--tobii_ip', metavar='TOBII_IP', type=str, default=None, help='tobii glasses ip')
parser.add_argument('-p', '--project_path', metavar='ARGAZE_PROJECT', type=str, default=None, help='json argaze project filepath')
- parser.add_argument('-b', '--borders', metavar='BORDERS', type=float, default=16.666, help='define left and right borders mask (%) to not track aruco out of these borders')
+ parser.add_argument('-b', '--borders', metavar='BORDERS', type=float, default=16.666, help='define left and right borders mask (%) to not detect aruco out of these borders')
parser.add_argument('-w', '--window', metavar='DISPLAY', type=bool, default=True, help='enable window display', action=argparse.BooleanOptionalAction)
args = parser.parse_args()
@@ -73,10 +73,10 @@ def main():
# Read video stream
video_ts, video_frame = tobii_video_stream.read()
- # Copy video frame to edit visualisation on it without disrupting aruco tracking
+ # Copy video frame to edit visualisation on it without disrupting aruco detection
visu_frame = video_frame.copy()
- # Hide frame left and right borders before tracking to ignore markers outside focus area
+ # Hide frame left and right borders before detection to ignore markers outside focus area
cv.rectangle(video_frame.matrix, (0, 0), (int(video_frame.width*args.borders/100), int(video_frame.height)), (0, 0, 0), -1)
cv.rectangle(video_frame.matrix, (int(video_frame.width*(1 - args.borders/100)), 0), (int(video_frame.width), int(video_frame.height)), (0, 0, 0), -1)
@@ -98,14 +98,14 @@ def main():
# Draw AOI
aoi_scene_projection.draw(visu_frame.matrix, (0, 0), color=(0, 255, 255))
- # Draw tracked markers
- ar_scene.aruco_tracker.draw_tracked_markers(visu_frame.matrix)
+ # Draw detected markers
+ ar_scene.aruco_detector.draw_detected_markers(visu_frame.matrix)
# Catch exceptions raised by estimate_pose and project methods
except (ArScene.PoseEstimationFailed, ArScene.SceneProjectionFailed) as e:
- # Draw tracked markers
- ar_scene.aruco_tracker.draw_tracked_markers(visu_frame.matrix)
+ # Draw detected markers
+ ar_scene.aruco_detector.draw_detected_markers(visu_frame.matrix)
cv.rectangle(visu_frame.matrix, (0, 50), (550, 100), (127, 127, 127), -1)
cv.putText(visu_frame.matrix, str(e), (20, 80), cv.FONT_HERSHEY_SIMPLEX, 1, (0, 255, 255), 1, cv.LINE_AA)
@@ -14,14 +14,14 @@ import numpy
def main():
"""
- Track ArUcoScene into Tobii Glasses Pro 2 camera video stream.
+ Detect ArUcoScene into Tobii Glasses Pro 2 camera video stream.
"""
# Manage arguments